Documentation
¶
Index ¶
- func AssertEmptyStr(t *testing.T, val string)
- func AssertNil(t *testing.T, val interface{})
- func AssertNotEmptyStr(t *testing.T, val string)
- func AssertNotNil(t *testing.T, val interface{})
- func Contains[T comparable](haystack []T, needle T) bool
- func ContainsAfter[T comparable](haystack []T, needle T, afterIdx int) bool
- func ContainsWithinRange[T comparable](haystack []T, needle T, lowerBound int, upperBound int) bool
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AssertEmptyStr ¶
Confirm that a string var is empty
func AssertNotEmptyStr ¶
Configm that a string var is not empty
func AssertNotNil ¶
Confirm that a value is not nil
func Contains ¶
func Contains[T comparable](haystack []T, needle T) bool
Check if a slice contains a specified element
func ContainsAfter ¶
func ContainsAfter[T comparable](haystack []T, needle T, afterIdx int) bool
Check if a slice contains a specified element, only between a certain range
func ContainsWithinRange ¶
func ContainsWithinRange[T comparable](haystack []T, needle T, lowerBound int, upperBound int) bool
Check if a slice contains a specified element, only between a certain range
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.